import { PencilIcon } from '@heroicons/react/solid'
import { Button } from 'src/components/Elements'
import {
  Form,
  FormDrawer,
  InputField,
  TextAreaField
} from 'src/components/Form'
import { Authorization, ROLES } from 'src/lib/authorization'
import * as z from 'zod'

import { useDiscussion } from '../api/getDiscussion'
import type { UpdateDiscussionDTO } from '../api/updateDiscussion'
import { useUpdateDiscussion } from '../api/updateDiscussion'

type UpdateDiscussionProps = {
  discussionId: string
}

const schema = z.object({
  title: z.string().min(1, 'Required'),
  body: z.string().min(1, 'Required')
})

export const UpdateDiscussion = ({ discussionId }: UpdateDiscussionProps) => {
  const discussionQuery = useDiscussion({ discussionId })
  const updateDiscussionMutation = useUpdateDiscussion()

  return (
    <Authorization allowedRoles={[ROLES.ADMIN]}>
      <FormDrawer
        isDone={updateDiscussionMutation.isSuccess}
        triggerButton={
          <Button startIcon={<PencilIcon className="h-4 w-4" />} size="sm">
            Update Discussion
          </Button>
        }
        title="Update Discussion"
        submitButton={
          <Button
            form="update-discussion"
            type="submit"
            size="sm"
            isLoading={updateDiscussionMutation.isLoading}
          >
            Submit
          </Button>
        }
      >
        <Form<UpdateDiscussionDTO['data'], typeof schema>
          id="update-discussion"
          onSubmit={async values => {
            await updateDiscussionMutation.mutateAsync({
              data: values,
              discussionId
            })
          }}
          options={{
            defaultValues: {
              title: discussionQuery.data?.title,
              body: discussionQuery.data?.body
            }
          }}
          schema={schema}
        >
          {({ register, formState }) => (
            <>
              <InputField
                label="Title"
                error={formState.errors['title']}
                registration={register('title')}
              />
              <TextAreaField
                label="Body"
                error={formState.errors['body']}
                registration={register('body')}
              />
            </>
          )}
        </Form>
      </FormDrawer>
    </Authorization>
  )
}
